@@ -89,7 +89,7 @@ class Dish(QuickRestoObject):
                  pack: float = None, ratio: float = None, recipe: str = None, sellingType: str = None,
                  storeQuantityKg: float = None, parentId: int = None,
                  parentItem: dict = None, price: float = 0.0, itemTitle: str = "", storeItemTag=None, **kwargs):
-        class_name: str = "ru.edgex.quickresto.modules.warehouse.nomenclature.Dish"
+        class_name: str = "ru.edgex.quickresto.modules.warehouse.nomenclature.dish.Dish"
 
         super().__init__(class_name=class_name, **kwargs)
         if (article != None): self._article: int = int(article)
