@@ -4,6 +4,14 @@ from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObj
 
 
 class DishSale(QuickRestoObject):
+    @property
+    def sale_place(self):
+        return self._sale_place
+
+    @property
+    def cooking_place(self):
+        return self._cooking_place
+
     def __init__(self, cookingPlace: dict = None, price: float = None, salePlace: dict = None, **kwargs):
         class_name = "ru.edgex.quickresto.modules.warehouse.nomenclature.dish.dishSale.DishSale"
 
