@@ -83,7 +83,7 @@ class SalePlace(QuickRestoObject):
                  tableScheme: dict = None, title: str = None, backupPrechecksTargetDevice: dict = None,
                  kkmOrganization1: dict = None, kkmOrganization2: dict = None,
                  prechecksTargetDevice: dict = None, reportTargetDevice: dict = None, **kwargs):
-        class_name: str = "modules.warehouse.nomenclature.sale_place.SalePlace"
+        class_name: str = "ru.edgex.quickresto.modules.warehouse.nomenclature.sale_place.SalePlace"
 
         super().__init__(class_name=class_name, **kwargs)
         self._automatic_encashment: bool = automaticEncashment
