@@ -60,8 +60,16 @@ class SemiProduct(QuickRestoObject):
     def recipe(self) -> str:
         return self._recipe
 
+    @property
+    def parent_id(self) -> int:
+        return self._parent_id
+
+    @property
+    def parent_item(self) -> dict:
+        return self._parent_item
+
     def __init__(self, version: int = None, serverRegisterTime: str = None, name: str = None, article: str = None,
-                 measureUnit: dict = None, storeItemTag: dict = None,
+                 measureUnit: dict = None, storeItemTag: dict = None, parentId:int = None, parentItem:dict = None,
                  ratio: float = None, minimalPrice: float = None, excludeDiscount: bool = None,
                  excludeMarkup: bool = None, storeQuantityKg: float = None,
                  limit: float = None, itemTitle: str = None, basePriceInList: float = None, pack: float = None,
@@ -94,3 +102,6 @@ class SemiProduct(QuickRestoObject):
         self._base_price_in_list: float = basePriceInList
         self._pack: float = pack
         self._recipe: str = recipe
+        
+        self._parent_id = parentId
+        self._parent_item = parentItem
\ No newline at end of file
